/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4; coding: utf-8 -*-
 *
 * Copyright © 2007 Björn Lindqvist <bjourne@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */
#include "utils.h"

/**
 * gdk_pixbuf_shade:
 *
 * Make each pixel in the pixbuf half as bright, but preserve its
 * alpha.
 **/
void
gdk_pixbuf_shade (GdkPixbuf *pixbuf)
{
    guchar *p = gdk_pixbuf_get_pixels (pixbuf);
    int width = gdk_pixbuf_get_width (pixbuf);
    int height = gdk_pixbuf_get_height (pixbuf);
    int rowstride = gdk_pixbuf_get_rowstride (pixbuf);
    if (gdk_pixbuf_get_has_alpha (pixbuf))
    {
        for (int y = 0; y < height; y++)
        {
            int i = y * rowstride;
            for (int x = 0; x < width; x++)
            {
                p[i++] >>= 1;
                p[i++] >>= 1;
                p[i++] >>= 1;
                i++;
            }
        }
    }
    else
    {
        for (int y = 0; y < height; y++)
        {
            int i = y * rowstride;
            for (int x = 0; x < width; x++)
            {
                p[i++] >>= 1;
                p[i++] >>= 1;
                p[i++] >>= 1;
            }
        }
    }
}

/**
 * gdk_rectangle_to_str:
 * @rect: a #GdkRectangle
 * @returns: a static string representation of the rectangle.
 **/
char *
gdk_rectangle_to_str (GdkRectangle rect)
{
    static gchar buf[256];
    g_snprintf (buf, 256, "(%d, %d)-[%d, %d]",
                rect.x, rect.y, rect.width, rect.height);
    return buf;
}

/**
 * gdk_rectangle_eq:
 * @r1: a #GdkRectangle
 * @r2: a #GdkRectangle
 * @returns: %TRUE if all parts of @r1 equals @r2, %FALSE otherwise.
 **/
gboolean
gdk_rectangle_eq (GdkRectangle r1,
                  GdkRectangle r2)
{
    return r1.x == r2.x && r1.y == r2.y &&
        r1.width == r2.width && r1.height == r2.height;
}

/**
 * gdk_rectangle_contains:
 * @rect: a #GdkRectangle
 * @returns: %TRUE if the x,y-coordinate is contained in the
 * rectangle, %FALSE otherwise. Border pixels are considered to be
 * contained.
 **/
gboolean
gdk_rectangle_contains (GdkRectangle rect,
                        int          x,
                        int          y)
{
    if (x >= rect.x && x <= (rect.x + rect.width) &&
        y >= rect.y && y <= (rect.y + rect.height))
        return TRUE;
    return FALSE;
}

void
gdk_window_draw_inset_frame (GdkWindow    *window,
                             GdkRectangle *rect,
                             GdkGC        *light_gc,
                             GdkGC        *dark_gc)
{
    int frame_x1 = rect->x - 1;
    int frame_y1 = rect->y - 1;
    int frame_x2 = rect->x + rect->width;
    int frame_y2 = rect->y + rect->height;

    gdk_draw_line (window, light_gc, frame_x2, frame_y1, frame_x2, frame_y2);
    gdk_draw_line (window, light_gc, frame_x1, frame_y2, frame_x2, frame_y2);
    gdk_draw_line (window, dark_gc, frame_x1, frame_y1, frame_x1, frame_y2);
    gdk_draw_line (window, dark_gc, frame_x1, frame_y1, frame_x2, frame_y1);
    
}

void
gdk_window_draw_rect (GdkWindow    *window,
                      GdkGC        *gc,
                      GdkRectangle *rect)
{
    if (rect->width <= 0 || rect->height <= 0)
        return;
    gdk_draw_rectangle (window, gc, TRUE,
                        rect->x, rect->y, rect->width, rect->height);
}

void
gdk_get_rects_around_rect (int            width,
                           int            height,
                           GdkRectangle  *inside,
                           GdkRectangle   around[4])
{
    GdkRectangle top = {
        0,
        0,
        width,
        inside->y
    };
    GdkRectangle bottom = {
        0,
        inside->y + inside->height,
        width,
        height - inside->y - inside->height
    };
    GdkRectangle left = {
        0,
        inside->y - 1,
        inside->x,
        inside->height + 2
    };
    GdkRectangle right = {
        inside->x + inside->width,
        inside->y - 1,
        width - inside->x - inside->width,
        inside->height + 2
    };
    around[0] = top;
    around[1] = bottom;
    around[2] = left;
    around[3] = right;
}


