/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4; coding: utf-8 -*- */
/**
 * This file contains tests for the extra GDK functions defined in
 * utils.h.
 **/
#include <src/utils.h>
#include <gtk/gtk.h>

#include <assert.h>

static void
rects_around_rect_checker (int width, int height, GdkRectangle i)
{
    GdkRectangle borders[4];
    gdk_get_rects_around_rect (width, height, &i, borders);

    GdkRectangle top = borders[0];
	assert (gdk_rectangle_eq (top, (GdkRectangle){0, 0, width, i.y}));

    GdkRectangle bottom = borders[1];
    assert (bottom.x == 0);
    assert (bottom.y == i.y + i.height);
    assert (bottom.width == width);
    assert (bottom.height == height - i.y - i.height);

    GdkRectangle left = borders[2];
    assert (left.x == 0);
    assert (left.y == i.y -1);
    assert (left.width == i.x);
    assert (left.height == i.height + 2);

    GdkRectangle right = borders[3];
    assert (right.x == i.x + i.width);
    assert (right.y == i.y - 1);
    assert (right.width == width - i.x - i.width);
    assert (right.height == i.height + 2);
}

/**
 * test_get_rects_around_rect
 *
 * Test that getting the four bordering #GdkRectangle:s around a
 * rectangle works as expected.
 **/
static void
test_get_rects_around_rect ()
{
    printf ("test_get_rects_around_rect\n");
    int outsides[] = {
        600, 400,
        10, 10,
    };
    int insides[] = {
        40, 40, 100, 100
    };

    for (int i = 0; i < G_N_ELEMENTS(outsides); i += 2)
    {
        for (int j = 0; j < G_N_ELEMENTS(insides); j += 4)
        {
            int width = outsides[i + 0];
            int height = outsides[i + 1];
            GdkRectangle inside = {
                insides[j + 0],
                insides[j + 1],
                insides[j + 2],
                insides[j + 3]
            };
            rects_around_rect_checker (width, height, inside);
        }
    }
    // Do manual simple sanity checks
    GdkRectangle in = {25, 25, 50, 50};
    GdkRectangle arounds[4];
    gdk_get_rects_around_rect (100, 100, &in, arounds);
	assert (gdk_rectangle_eq (arounds[0],
							  (GdkRectangle){0, 0, 100, 25}));
	assert (gdk_rectangle_eq (arounds[1],
							  (GdkRectangle){0, 75, 100, 25}));
	assert (gdk_rectangle_eq (arounds[2],
							  (GdkRectangle){0, 25 - 1, 25, 50 + 2}));
	assert (gdk_rectangle_eq (arounds[3],
							  (GdkRectangle){75, 25 - 1, 25, 50 + 2}));
}

int
main (int argc, char *argv[])
{
    gtk_init (&argc, &argv);
    test_get_rects_around_rect ();
    printf ("1 test passed.\n");
}


